@@ -60,10 +60,6 @@ def getRemoteAddr(headers, whatap_dict):
         header_val = headers.get(conf.trace_http_client_ip_header_key)
         if header_val:
             return header_val.split(',')[0].strip()
-    x_forwarded_for = headers.get("x-forwarded-for")
-    if x_forwarded_for:
-        x_forwarded_for = x_forwarded_for.split(',')[0].strip() if ',' in x_forwarded_for else None
-        return x_forwarded_for
     if whatap_dict:
         return whatap_dict.get(_REMOTE_ADDR)
 
